unsupported_adapter_exits_successfully

Function unsupported_adapter_exits_successfully 

pub fn unsupported_adapter_exits_successfully(adapter: &str) -> bool
Adapters that are valid in the ecosystem but not driven by rustauth db migrate.

For these we print guidance and exit successfully (Better Auth parity for Prisma/Drizzle).